bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift C ## 38. Aventiure
___________________________________________________ #### Auentv wie des herren Dietriches <rechen> alle wrden #### erslagen
| ### <Do> hort man allenthalben iamer also groz ### daz palas vn– tvrne von dem wofe erdoz ### do hort ez ovch von Berne ein Dietriches man ### dvrch disiv starchen mære wie balder gahen began ### Do sprach er zvo dem fvrsten hort min her Dietrich ### swaz ich her gelebt han so reht vnmvgelich ### gehort ich klage nie mere als ich nv han vernomen ### ich wæn der kunic Ezele ist selbe zv dem schaden chomen
###### 2295 | ### Wie moehtens anders alle haben solhe not ### der chvnic oder Chriemh' ir einez daz ist tot ### von den chunen gesten dvrch ir nit gelegen ### ez weinet harte sere vil manic vz erwelter degen
###### 2296 | ### Do sprach der helt von Berne mine lieben man ### nvne gahet niht ze sere swaz hie hant getan ### die ellenden rechen des get in michel not ### vn– lat si des geniezen daz ich in minen vride bot
| ### Do sprach der chvne Wolfhart ich wil dar gan ### vn– wil der mære vragen waz si haben getan ### vn– wilz iv sagen denne vil lieber herre min ### als ich ez rehte ervinde waz div rede mvege sin
###### 2298 | ### Do sprach der herre Dietrich swa man zornes sich versiht ### ob vngefvgiv vrage denne da gesiht ### daz betrvebet rechen vil lihte danne ir mvot ### iane wil ich niht Wolfhart daz ir die vrage da zin tvot
###### 2299 | ### Do hiez er Helpfrichen vil balde dar gan ### vn– bat in daz ervinden an Ezelen man ### oder an den gesten selben waz wære da geschehn ### done het er nie von lvten so grozer iamer mer gesehen
###### 2300 | ### Der bote vragte balde waz ist hie getan ### do seit man im div mære da ist vil gar zergan ### swaz wir frevden heten in der Hvnen lant ### hie lit erslagen Rvdeger von der Bvrgonden hant [83v]
###### 2301 | ### Die mit im dar in chomen der ist einer niht genesen ### done chunde Helpfriche leider nimmer wesn ### iane sagt er siniv mære so reht vngerne nie ### der bote do hin widere vil sere weinende gie
| ### Waz habt ir vns erfvnden sprach do Dietrich ### wie weinet ir so sere degen Helpfrich ### do sprach der chvne reche ich mac wol balde chlagen ### den gvten Rvdegere hat vns her Gernot erslagen
###### 2303 | ### Do sprach der helt von Berne daz ensol niht wellen got ### daz wær ein starchiv rache vn– ovch des tivfels spot ### wa mite hete Rvdeger an in daz verscholt ### ia ist mir daz wol chvende er ist den Bvrgonden holt
###### 2304 | ### Do sprach der chvene Wolfhart vn– heten siz getan ### so solt ez in allen an ir lebn gan ### ob wirz in vertrvgen des wæren wir geschant ### ia hat vns vil gedienet des gvten Rvdegeres hant
###### 2305 | ### Der vogt Amelunge bat iz ervarn baz ### vil harte seneliche er in venster saz ### do hiez er Hildebrande zvo den gesten dan ### daz an in erfvnde waz da wære getan
| ### Der stvrme chvne reche meister Hildebrant ### weder schilt noch wafen trvger an der hant ### er wolde in sinen zvhten zv den gesten gan ### von siner swester chinde wart im ein strafen getan
###### 2307 | ### Do sprach der grimme Wolfhart welt ir dar blozer gan ### sone mag ez ane ein schelten nimmer wol gestan ### so mvzet ir lasterliche tvon die widervart ### ob ir dar chomet gewafent daz eteslicher wol bewart
###### 2308 | ### Do garte sich der wise dvrch des tvmben rat ### e iz erfunde Hildebrant do waren in ir wat ### alle Dietriches rechen vn– trvgen swert enhant ### dem helde was iz leide vil gerne het erz erwant
###### 2309 | ### Er vragte war si wolden wir wellen mit iv dar ### waz ob von Tronege Hagene dest wirs getar ### gein iv mit spotte sprechen des er chan wol gepflegen ### do er die rede gehorte da von gestattes in der degen
| ### Do sach der chvne Volker wol gewafent gan ### die rechen von Berne die Dietriches man ### begvrtet mit den swerten ir schilde vor der hant ### er sagtez sinen herren vzer Bvrgonden lant
###### 2311 | ### Do sprach der videlære ich sihe dort her gan ### so rehte vientliche die Dietriches man ### gewafent vnder helme si wellent vns bestan ### mich nimt des michel wnder waz wir den rechen haben getan
###### 2312 | ### In den selben ziten chom ovch Hildebrant ### do sazter fvr die fvze sinen schildes rant ### er begvnde vragen die Guntheres man ### owe ir gvten degene waz het iv Rvdeger getan
###### 2313 | ### Mich hat min herre Dietrich her zv ziv gesant ### ob erslagen hete iwer deheines hant ### den edeln marcgraven als vns ist geseit ### wir [84r]enchvnden vberwinden niht div groezlichen leit
| ### Do sprach der grimme Hagene daz mære ist vngelogen ### wie wol ich iv des gvnde het ivch der bot betrogen ### dvrch Rvdegeres liebe daz lebte noch sin lip ### den immer mvgen weinen bediv man vn– ovch div wip
###### 2315 | ### Do si daz rehte erhorten daz er wære tot ### do chlagten in die degene ir triwe in daz gebot ### den Dietriches mannen sah man træhene gan ### vber bærte vn– vber chinne in was vil leide getan
###### 2316 | ### Der herzoge vzer Berne Sigestap do sprach ### nv hat gar ein ende genomen der gemach ### den vns ie fvogte Rvdeger nach vnser leide tagen ### frevde ellender diete lit von iv degenen erslagen
###### 2317 | ### Do sprach von Amelvngen der degen <Wlfwin> ### vn– ob ich hivte sæhe tot den vater min ### mir en wrde nimmer leider denne vmbe sinen lip ### owe wer sol nv troesten des gvten marcgraven wip
| ### Do sprach in zornes mvote der chvene Wolfhart ### wer wiset nv die rechen so manige hervart ### also der marcgrave vil diche hat getan ### owe vil edel Rvdeger deich dinen tot gelebt han
###### 2319 | ### Wolfprant vn– Helpfrich vn– Helmnot ### mit allen ir frivnden si weinten sinen tot ### vor svften mohte vragen niht mer Hildebrant ### er sprach nv tvot ir degene dar nach min herre hat gesant
###### 2320 | ### Gebt vns Rvdegeren so toten vz dem sal ### an dem gar mit iamer lit vnser vrevden val ### vn– lat vns an im dienen daz er ie hat began ### an vns vil grozer triwen vn– ovch an manigem vremden man
###### 2321 | ### Wir sin ovch ellende als Rvdeger der degen ### wes lazet ir vns biten lat in vns after wegen ### tragen daz wir nach tode lonen noch dem man ### wir hetenz pillicher bi sime lebene getan
| ### Do sprach der kunec Gvnther nie dienest wart so gvot ### den ein frivnt frivnde so nach tode tvot ### daz heiz ich stæte triwe swer die chan began ### ir lonet im von schulden wander iv liebe hat getan
###### 2323 | ### Wie lange svln wir vlegen sprach Wolfhart der degen ### sit vnser trost der beste ist von iv tot belegen ### vn– wir sin leider mere mvgen niht gehaben ### lat in vns tragen hinnen da wir den rechen begraben
###### 2324 | ### Des antwrt Volker niemen in iv git ### nemt in in dem hvse da der degen lit ### mit sinen tiefen wnden gevallen in daz blvot ### so ist ez ein voller dienest den ir hie Rvdegere tvot
###### 2325 | ### Do sprach der chvne Wolfhart lat sin her spileman ### irn dvrfet vns niht reizen ir habt vns leit getan ### toerst ich vor mime herren so chomt irs in not ### des mvzen wir ez lazen wan er vns strit mit iv verbot
| ### Do sprach der [784v]videlære der vorht ist gar ze vil ### swaz im verbivtet derz allez lazen wil ### daz enchan ich niht geheizen rehten heldes mvot ### div rede dvhte Hagenen von <sime> hergesellen gvot
###### 2327 | ### Welt ir den spot niht lazen sprach aber Wolfhart ### ich entrihtiv liht die seiten swenne ir die widervart ### ritet gegen Rine daz irz wol mvgt gesagen ### iwer vbermveten mag ich langer niht vertragen
###### 2328 | ### Do sprach der videlære swenn ir die seiten min ### verirret gvoter done der iwer helmes schin ### mac wol trvebe werden von der miner hant ### swie ich halte geriten in der Burgonden lant
###### 2329 | ### Do wolder zvo zim springen wandaz in niht enlie ### Hildebrant sin oehaim in vaste zim gevie ### ich wæn dv woldest woten dvrch dinen tvmben zorn ### mines herren hvlde wir heten immer mer verlorn
###### 2330 | ### Lat ab den lewen meister er ist so grimme gemvot ### chvmt er mir zen handen sprach Volker der helt gvot ### het er die werlde alle mit siner hant erslagen ### ich slah in daz erz widerspel nimmer mere darf gesagen
| ### Des wart vil harte erzvrnet der Bernære mvot ### den schilt gezvchte Wolfhart ein sneller degen gvot ### alsam ein lewe wilder lief er vor in dan ### im wart eine gæhez volgen von sinen frivnden getan
###### 2332 | ### Swie witer sprvnge er pflæge fvr des sales want ### doch ergahet in vor der stiegen der alde Hiltebrant ### er wolde in vor im lazen niht chomen in den strit ### si fvnden daz si svochten an den ellenden sit
###### 2333 | ### Do gespranch zvo Hagene maister Hildebrant ### div swert man hort erchlingen an ir beider hant ### si waren harte erzvrnet vil wol erchos manz sint ### von ir beider wafen gie der vivr roter wint
###### 2334 | ### Di wrden do gescheiden in des strites not ### daz taten die von Berne als in ir chraft gebot ### zehant do wande Hildebrant von Hagene balde dan ### do lief der starche Wolfhart den chvnen Volkeren an
###### 2335 | ### Er slvoc den videlære vf den helm gvot ### daz des swertes ecke vnz an die spangen wot ### daz vergalt mit ellen der chvne spileman ### do slvoger Wolfharten daz er strvchen began
###### 2336 | ### Fivr vz den ringen des hiwen si genvoc ### haz ir ieslicher dem andern vaste trvoc ### do schiet do von Berne der degen Wlfwin ### ob er ein helt niht wære des enchunde niht gesin
| ### Gvnther der vil chvne mit williger hant ### enpfie die helde mære von Amelunge lant ### Giselher der starche div liehten helm vaz ### der frvmt er da vil manigez von blvote rot vn– naz
###### 2338 | ### Danchwart Hagenen brvder was ein grimmech man ### swaz er da vor hete in strite getan ### den Ezeln rechen daz was gar ein [85r]wint ### alrest vaht tobeliche des kvnen Adrianes kint
###### 2339 | ### <Gerbart> vn– Wichart Helpfrich vn– Rischart ### die heten in manigen stvrmen vil selten sih gespart ### des brahten si wol innen die Guntheres man ### do sach man Wolfpranden in stvrme herliche gan
###### 2340 | ### Da streit er als er wote der alde Hildebrant ### vil manic kvner reche vor Wolfhartes hant ### mit tode mvse vallen von swerten in daz blvot ### svs rachen Rvdegere die rechen <kvne> vn– gvot
###### 2341 | ### Sigestap von Berne als im sin ellen riet ### hey waz er in dem sturme der herten helm schriet ### den sinen vianden Dietriches swester svon ### der chvnde in dem stvrme bezzers nimmer niht getvon
###### 2342 | ### Volker der vil starche do er daz ersach ### daz Sigestap der chvene den blvtigen bach ### hiw vz herten ringen daz was dem degene zorn ### do spranger im begegene do hete Sigestap verlorn
###### 2343 | ### von dem videlære vil schiere al da daz lebn ### er begunde in siner chunste al solhen teil da gebn ### daz er von sime swerte mvse ligen tot ### daz rach der alde Hildebrant als im sin ellen daz gebot
###### 2344 | ### Owe vil liebes herren sprach meister Hildebrant ### der hie lit erstorben von Volkeres hant ### nvne sol der videlære langer niht genesen ### zorn der Hildebrandes chunde grimmer niht gewesen
###### 2345 | ### Do slvger Volkere daz im div helmbant ### stvben allenthalben zvo des sales want ### von helme vn– ovch von schilde dem chvnen spileman ### da von der videlære do den ende da gewan
| ### Do drvngen zvo dem strite die Dietriches man ### si slvgen daz die ringe vil hohe wæten dan ### vn– daz man ort der swerte inme gewelbe stechen sach ### si hiwen vz den helmen den heize <vliezenden> bach
###### 2347 | ### Do sach von Tronege Hagene Volkeren tot ### daz was zer hochgecite sin aller meistiv not ### die er da hete gewnnen an magen vn– an man ### owe wie grimme Hagene den helt rechen began
###### 2348 | ### Nvne sol es niht geniezen der alde Hildebrant ### min helfe lit erslagene hie von des heldes hant ### der beste hergeselle den ieman gewan ### den schilt den rvchter hoher do gie er howende dan
###### 2349 | ### Helpfrich der vil starche Danchwarten slvoc ### Gvnther vn– Giselher den was ez leit genvoc ### do si in sahen vallen in der starchen not ### er het wol vergolten mit sinen handen sinen tot
###### 2350 | ### Swie vil von manigen landen gesamnet wære dar ### vil fvrsten chreftekliche gegen ir chleinen schar ### wæren die kristen lvte wider si niht gewesen ### si wæren mit ir ellen vor allen heiden wol genesen
| ### Die wile gie do Wolfhart beide wider vn– dan ### allez [85v]howende die Gvntheres man ### er was die dritten chere den palas zende chomen ### ia het er den chunigen so vil der rechen da genomen
###### 2352 | ### Do rief der starche Giselher Wolfharten an ### ovve daz ich so grimmen vient ie gewan ### edel ritter chvene nv wendet gegen mir ### si chomen zv ein ander sit mit ellenthafter gir
###### 2353 | ### Wolfhart gein Giselhere chert in den strit ### do slvg ir ietwedere vil manige <wnden> wit ### so rehte chreftechliche er zvo dem kunige dranch ### daz im daz blvot von fvzen al vber daz hovbet sin <gespranch>
###### 2354 | ### Mit grimmen slegen swinden der edeln Vten chint ### enpfie vil pitterliche den chvenen rechen sint ### swie chvne Wolfhart wære er mohte niht genesen ### vor dem ivngen kvnige niemen dorfte chvner wesen
###### 2355 | ### Do slvg er Wolfharte dvrch eine prvnne gvot ### daz im von der wnden vil sere vloz daz blvot ### er wnte zvo dem tode den Dietriches man ### ez enhet ân einen rechen ander niemen getan
| ### Also der chvne Wolfhart der wnden enpfant ### den schilt liez er do vallen hoher an der hant ### hvber daz starchez wafen daz was scharpf genvoc ### dvrch helm vn– dvrch ringe der helt do <Giselhern> slvoc
###### 2357 | ### Si heten beide ein ander den grimmen tot getan ### done lebt ovch nv niht mere der Dietriches man ### wan Hildebrant aleine do er den neven vallen sach ### im wæn vor sime tode so rehte leide nie geschach
###### 2358 | ### Ovch warn gar gevallen Guntheres degene ### niwan si einen zwene er vn– Hagene ### si stvnden in dem blvote tief unz an div knie ### Hildebrant harte balde hin vber sinen neven gie
###### 2359 | ### Er besloz in mit armen vn– wolde in tragen dan ### mit im vzem hvose er mvse in ligen lan ### er was ein teil ze swære wider in daz blvot ### enpfiel er im vz handen do blicht vf der degen gvot
###### 2360 | ### Do sprach der totwnde vil lieber oeheim min ### irn mvget an disen ziten mir niht frvom gesin ### nv hvtet ivch vor Hagene ia dvnchet ez mich gvot ### er treit in sime hercen einen grimmigen mvot
| ### Vnde ob mich mine mage nach tode wellen chlagen ### den næhsten vn– den besten den svlt ir daz sagn ### daz si nach mir niht weinen daz ist ane not ### vor eines kuniges handen lige ich hie herlichen tot
###### 2362 | ### Ich han ovch so vergolten hier inne minen lip ### daz ez wol mvgen beweinen der gvten ritter wip ### ob ivch des iemen vrage so mvget ir balde sagen ### vor min eines handen ir lit wol hundert erslagen
###### 2363 | ### Do gedaht ovch Hagene an den spileman ### dem <der> alde Hildebrant sin lebn an gewan [86r] ### do sprach er zv dem kvnige ir geltet miniv leit ### ir habt vns hinne erbvnnen vil maniges rechen gemeit
###### 2364 | ### Er slvog vf Hildebranden daz man wol vernam ### Balmvngen diezen daz Sivride nam ### Hagene der chune da er den rechen slvoc ### do widerstvnt im Hildebrant der im vil wenic iht vertrvoc
###### 2365 | ### Der Wolfhartes oeheim slvog ein wafen breit ### vf Hagenen von Tronege daz ovch vil sere sneit ### done chunder niht verwnden den Gvntheres man ### do slvog aber in Hagene dvrch eine prvnne wolgetan
###### 2366 | ### Also meister Hildebrant der wnden enpfant ### do vorht er schaden mere von der Hagenen hant ### den schilt warf er vber rvcke der Dietriches man ### mit der starchen wnden der helt vil chvome danne entran
| ### Dar inne was niemen lebnde als ich gesaget han ### niwan die einen zwene Gunther vn– ovch sin man ### mit blvte gie bervnnen der alde Hildebrant ### er brahte leidiv mære da er sinen herren vant
###### 2368 | ### Do saher trvrechliche sizzen hie den man ### leides michel mere der fvrste do gewan ### als er Hildebranden ersach von blvte rot ### do vragt er in der mære als im div sorge gebot
###### 2369 | ### Wan sagt ir mir meister wie sit ir so naz ### <worden> von dem blvote oder wer tet iv daz ### ich wên ir mit den gesten zem hvse habt gestriten ### ich verbot ez iv so sere do wær ez pillich vermiten
###### 2370 | ### Swie vbel disiv mære mir sten ze sagene ### er sprach dise wnden slvoc mir Hagene ### do ich vz dem hvse wolde wenden ### wie chvom <ich> mit dem lebene dem selben valande entran
| ### Do sprach der Bernære vil reht ist iv geschehn ### do ir mich frivntschefte den helden hortet iehn ### daz ir den vride brachet den ich in het gegeben ### hete ihs niht immer schande ir soldet vliesen daz leben
###### 2372 | ### Nvne zvrnet niht so sere min herre Dietrich ### an mir vn– minen frivnden der schade ist gremlich ### wir wolden Rvdegeren getragen haben dan ### des enwolden vns niht gvnnen des kvnec Guntheres man
###### 2373 | ### So we mir dirre leide ist Rvdeger doch tot ### daz mvz mir sin ein iamer vor aller miner not ### Gotelint div edele ist miner basen chint ### ach we der armen weisen die da ze Bechelaren sint
###### 2374 | ### Riwen vn– ovch leides mant in do sin tot ### er begvnde starche weinen des gie dem helede not ### owe getriwer helfe der ich verlorn han ### iane vberwinde ich nimmer des kunic Ezeln man
###### 2375 | ### Er sprach ze Hildebrande mvget ir mir doch sagen ### wer der degen wære der in da hat erslagn ### er sprach daz tet mit chreften der starche Gernot ### vor Rvdegers handen [86v]mvos ovch der degn ligen tot
| ### Er sprach meister Hildebrant nv saget minen man ### daz si sich balde wafen ia wil ich dar gan ### vn– heizet mir gewinnen min liehtez wichgewant ### ich wil selbe vragen die helede vz Burgonden lant
###### 2377 | ### Do sprach meister Hildebrant wer sol zvo ziv gen ### swaz ir habt der lebenden die seht ir bi iv sten ### daz bin ich alterseine die andern die sint tot ### do erschracter dirre mære des gie dem rechen groziv not
###### 2378 | ### wander leit so grozez zer werlde nie gewan ### er sprach unt sint erstorben alle mine man ### so hat min got vergezzen ich was ein kunic rich ### nv mag ich wol heizen der vil arme Dietrich
###### 2379 | ### Wie chundez sich gefvgen sprach aber Dietrich ### daz si alle sint erstorben die helde lobelich ### von den strit mvden die doch heten not ### wan dvrch min vngelvcke in wære vremde noch der tot
###### 2380 | ### Owe vil lieber Wolfhart sol ich dich han verlorn ### so mac mich balde riwen daz ich ie wart geborn ### Sigestap vn– Wlfwin vn– ovch Wolfprant ### wer sol mir danne helfen in der Amelvnge lant
###### 2381 | ### Helpfrich der vil chvene vn– ist mir der erslagen ### Gerbart vn– Wichart wie solde ich die verklagen ### daz ist an minen frevden mir der leste tac ### owe daz vor leide niemen sterben ne mac

<<< Übersicht <<< vorige Seite nächste Seite >>>